
#--EHF    
#--FILE: users.nawk 
#--
#-- Usage: nawk -f users.nawk INFILE > OUTFILE
#--
#--    "INFILE" is the file being read (in this case the aliases file)
#--    "OUTFILE" is where output will be saved 
#--
#-- After generating the LDIF file, import it into the Directory Server with:
#--
#--  ldapmodify -D "cn=Directory Manager" -w PASSWORD -h HOST -p PORT -f OUTFILE
#--  
#--  **do not use "-a" (add) flag since a changetype "modify" is being used**

{

  while (getline)
  {

	#
	# split line being read into two fields;
	# white-space is default delimiter;
	# example -->
	# The follwing line:
	#    user: user@domain.com
	# would be split into: 
	#   key[1]	key[2]
	#   user:	user@domain.com
	#
	split($0, key);
	
	# get rid of ':' from first field
	sub(/:/, "", key[1]); 

	#
	# count the number of chars in key
	#
	key_char_count = length(key[1]);

	# 
	# split key[2] using '@' as delimiter;
	# example -->
	# The following line:
	#    user@domain.com
	# would be split into:
	#   entry[1]	entry[2] 
	#   user	domain.com
	#
	split(key[2], entry, /\@/); 

	#
	# print LDIF data for users.
	# Aliases 3 chars or less are users.
	#
	if ( key_char_count <= 3 && key[2] ~ /\@/ )
	{

	   printf("dn: uid=%s, ou=People, o=cypress.com\n", key[1]);
	   printf("changetype: modify\n");
	   printf("add: objectclass\n");
	   printf("objectclass: MailRecipient\n");
	   printf("-\n");
	   printf("replace: mail\n");
	   printf("mail: %s@cypress.com\n", key[1]);
	   printf("-\n");
	   printf("replace: mailroutingaddress\n");
	   printf("mailroutingaddress: %s\n", key[2]);
	   printf("-\n");
	   printf("replace: mailhost\n");
	   printf("mailhost: %s\n", entry[2]);
	   printf("\n");

	}

  } # while

}
